Form Handling and Rendering for Pyramid
=======================================

Scott Torborg - `Cart Logic <http://www.cartlogic.com>`_

Form rendering and validation for Pyramid. Doesn't render HTML itself, so you
have full control over form markup.

Heavily inspired by the :py:mod:`pyramid_simpleform` package, rewritten to work
with :py:mod:`WebHelpers2` and Python 3 and fix some issues with the original.

Contents
========

.. toctree::
    :maxdepth: 2

    quickstart
    recipes
    logging
    api
    contributing


Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
